Stan Math Library: stan/math/rev/scal/fun/lgamma.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
lgamma.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <boost/math/special_functions/digamma.hpp>`
`#include <boost/math/special_functions/gamma.hpp>`
`#include <valarray>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::lgamma (const stan::math::var &a)
| The log gamma function for variables (C99). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.